# pydistcheck

[![PyPI Version](https://img.shields.io/pypi/v/pydistcheck.svg?logo=pypi&logoColor=white)](https://pypi.org/project/pydistcheck)
[![PyPI downloads](https://static.pepy.tech/badge/pydistcheck)](https://pypi.org/project/pydistcheck)
[![Documentation Status](https://readthedocs.org/projects/pydistcheck/badge/?version=latest)](https://pydistcheck.readthedocs.io/)
[![GitHub Actions](https://github.com/jameslamb/pydistcheck/workflows/unit-tests/badge.svg?branch=main)](https://github.com/jameslamb/pydistcheck/actions/workflows/unit-tests.yml)
[![GitHub Actions](https://github.com/jameslamb/pydistcheck/workflows/smoke-tests/badge.svg?branch=main)](https://github.com/jameslamb/pydistcheck/actions/workflows/smoke-tests.yml)

> **Warning**
>
> This project is very-very-very new and will change significantly.
> If I was you, **I wouldn't use it**.

## Installation

Install with `pipx`.

```shell
pipx install pydistcheck
```

## Minimal Example

Given a Python distribution...

```shell
pydistcheck dist/*.tar.gz
```

## Related Projects

* https://pypi.org/project/inspect4py/
* https://github.com/regebro/pyroma

## References

* Python packaging guides: https://packaging.python.org/en/latest/guides/#
